#r "System.Windows.Forms"
using System.Windows.Forms;
using System.Resources;
using System.IO;

// 現在の図面のレイヤを取得する
var doc = Application.ActiveDocument;
var layerTable = doc.LayerTable;
 
doc.UndoManager.BeginUndoUnit();

// 未使用のレイヤを削除する
int unusedLayerCount = RemoveUnusedLayer(layerTable.RootLayer);

// 空のレイヤグループを削除する
int emptyGroupCount = RemoveEmptyLayerGroup(layerTable.RootLayer);

doc.UndoManager.EndUndoUnit();

string resxPath = Path.Combine(Path.GetDirectoryName(ScriptFilePath), Application.Settings.LanguageCode == "ja" ? "Resources.ja.resx" : "Resources.resx");
ResXResourceSet resx = new ResXResourceSet(resxPath);
string message = string.Format(resx.GetString("ConfirmMessage"), unusedLayerCount, emptyGroupCount);
MessageBox.Show(message);



/// <summary>
/// 指定したレイヤまたはその子レイヤから未使用のレイヤを削除する。
/// </summary>
/// <param name="layer">レイヤまたはレイヤグループ</param>
/// <returns>削除した未使用のレイヤの数</returns>
int RemoveUnusedLayer(Layer layer)
{
	int count = 0;

	// レイヤグループの場合は、子レイヤの中から未使用のレイヤを削除する
	if(layer.IsGroup)
	{
		Layer[] array = layer.ChildLayers.ToArray();
		foreach(var childLayer in array)
		{
			count += RemoveUnusedLayer(childLayer);
		}
	}
	// レイヤの場合は、未使用なら削除する（カレントレイヤは除く）
	else
	{
		if(!layer.IsInUse && !layer.IsCurrent)
		{
			layer.ParetLayer.ChildLayers.Remove(layer);
			count += 1;
		}
	}
	
	return count;
}


/// <summary>
/// 指定したレイヤまたはその子レイヤから空のレイヤグループを削除する。
/// </summary>
/// <param name="layer">レイヤまたはレイヤグループ</param>
/// <returns>削除した空のレイヤグループの数</returns>
int RemoveEmptyLayerGroup(Layer layer)
{
	int count = 0;

	// レイヤグループの場合
	if(layer.IsGroup)
	{
		// 子レイヤがレイヤグループの場合は、そのグループ内も調べる
		Layer[] array = layer.ChildLayers.ToArray();
		foreach(var childLayer in array)
		{
			if(childLayer.IsGroup)
			{
				count += RemoveEmptyLayerGroup(childLayer);
			}
		}

		// 子レイヤがないならレイヤグループを削除する
		if(layer.ChildLayers.Count == 0)
		{
			layer.ParetLayer.ChildLayers.Remove(layer);
			count += 1;
		}
	}
	
	return count;
}
